###################################################
### chunk number 1: aneurism load
###################################################
library(survBayes)
data(aneurism.data)
aneurism.data[1:11,]


###################################################
### chunk number 2: aneurism fit
###################################################
control<-survBayes.control(sigma.lbh.1 = 0.01, rate.sigma.lbh.1 = 1e-3, shape.sigma.lbh.1 = 1e-3)
aneurism.res<-survBayes(Surv(left,right,cens*3,type="interval")~mo+loc+frailty(gr,dist="gamma"), data = aneurism.data, burn.in = 0, number.sample = 10, control = control)
str(aneurism.res) 


###################################################
### chunk number 3: aneurismcoda
###################################################
raftery.diag(aneurism.res$beta)
raftery.diag(aneurism.res$lbh.coef)
raftery.diag(aneurism.res$sigma.lbh) 
raftery.diag(aneurism.res$z.cluster)
raftery.diag(aneurism.res$mu.cluster) 


###################################################
### chunk number 4: aneurismplot
###################################################
beta.est<-apply(aneurism.res$beta,2,mean)
baseline.hazard<-survBayes.baseline.hazard(aneurism.res,start=1,type="cum",n.inter=0)
time<-baseline.hazard$time 
Lambda0<-baseline.hazard$cum.base.haz
surv.base<-exp(-Lambda0) 
plot(time,surv.base,type="l",xlab="time[years]",ylab="Survival function",lty=1,ylim=c(0,1))
lines(time,surv.base^exp(beta.est["mo"]),type="l",lty=2)
lines(time,surv.base^exp(beta.est["loc"]),type="l",lty=3)
lines(time,surv.base^exp(sum(beta.est[c("mo","loc")])),type="l",lty=5)
leg.names<-c("mo=0, loc=0", "mo=1, loc=0","mo=0, loc=1","mo=1, loc=1") 
legend(4,1,leg.names,lty=c(1,2,3,5),bty="n") 


